@@ -1,22 +1,9 @@
 from __future__ import annotations
-from . path import Path
-from . pd_handle import PDHandle
+from . path_dict import PathDict
 
 
-def pd(data: dict | list, str_sep="/", raw=False) -> PDHandle:
-    """
-    Creates and returns a handle on the given data.
+pd = PathDict
 
-    Args:
-    - `data` - Must be a list or dict.
-    - `str_sep` - Look within path strings for this separator and use it to split the path.
-    - `raw` - If `True`, do not interpret paths. So wildcards (`*`) are interpreted as a usual key, and tuples will be interpreted as keys  as well.
-
-    Returns:
-    - A handle that references the root of the given data dict or list.
-    """
-    path = Path([], str_sep=str_sep, raw=raw)
-    return PDHandle(data, path)
 
 ################################################################################
 # To be used like this:
@@ -39,5 +26,5 @@ def pd(data: dict | list, str_sep="/", raw=False) -> PDHandle:
 # For the .do_something() after .at(), we need to tell the do_something() method
 # what the path is and wheater or not it is a wildcard path.
 
-# If .at(path) has wildcards, then we really need a PDMultiHandle
-# After the .do_something(), a regular PDHandle will be returned, at its previous path
+# If .at(path) has wildcards, then we really need a MultiPathDict
+# After the .do_something(), a regular PathDict will be returned, at its previous path
